/*
 *  jDTAUS Core RI Commons Logging
 *  Copyright (c) 2005 Christian Schulte
 *
 *  Christian Schulte, Haldener Strasse 72, 58095 Hagen, Germany
 *  <cs@jdtaus.org> (+49 2331 3543887)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.logging.ri.commons;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jdtaus.core.container.ContainerInitializer;
import org.jdtaus.core.container.Dependency;
import org.jdtaus.core.container.Implementation;
import org.jdtaus.core.container.ModelFactory;
import org.jdtaus.core.container.Properties;
import org.jdtaus.core.container.Property;
import org.jdtaus.core.container.PropertyException;
import org.jdtaus.core.logging.spi.Logger;

/**
 * jDTAUS Core SPI Commons Logging {@code Logger} implementation.
 * <p>The name of the commons logger is specified by property {@code name}.
 * Property {@code name} defaults to {@code org.jdtaus.runtime}.</p>
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: CommonsLoggingLogger.java 5014 2008-07-04 10:41:02Z schulte2005 $
 *
 * @see org.jdtaus.core.container.Container
 * @see #initialize()
 */
public final class CommonsLoggingLogger implements ContainerInitializer,
                                                     Logger
{
    //--Implementation----------------------------------------------------------

// <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:jdtausImplementation
    // This section is managed by jdtaus-container-mojo.

    /** Meta-data describing the implementation. */
    private static final Implementation META =
        ModelFactory.getModel().getModules().
        getImplementation(CommonsLoggingLogger.class.getName());
// </editor-fold>//GEN-END:jdtausImplementation

    //----------------------------------------------------------Implementation--
    //--Constructors------------------------------------------------------------

// <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:jdtausConstructors
    // This section is managed by jdtaus-container-mojo.

    /**
     * <code>CommonsLoggingLogger</code> implementation constructor.
     *
     * @param meta Implementation meta-data.
     *
     * @throws NullPointerException if <code>meta</code> is <code>null</code>.
     */
    private CommonsLoggingLogger(final Implementation meta)
    {
        super();
        if(meta == null)
        {
            throw new NullPointerException("meta");
        }
        this.initializeProperties(meta.getProperties());
    }
    /**
     * <code>CommonsLoggingLogger</code> dependency constructor.
     *
     * @param meta dependency meta-data.
     *
     * @throws NullPointerException if <code>meta</code> is <code>null</code>.
     */
    private CommonsLoggingLogger(final Dependency meta)
    {
        super();
        if(meta == null)
        {
            throw new NullPointerException("meta");
        }
        this.initializeProperties(meta.getProperties());
    }

    /**
     * Initializes the properties of the instance.
     *
     * @param meta the property values to initialize the instance with.
     *
     * @throws NullPointerException if {@code meta} is {@code null}.
     */
    private void initializeProperties(final Properties meta)
    {
        Property p;

        if(meta == null)
        {
            throw new NullPointerException("meta");
        }

        p = meta.getProperty("name");
        this.pName = (java.lang.String) p.getValue();

    }
// </editor-fold>//GEN-END:jdtausConstructors

    //------------------------------------------------------------Constructors--
    //--ContainerInitializer----------------------------------------------------

    /** Commons logging logger. */
    private Log logger;

    /**
     * Requests a commons logging logger for the name given by property
     * {@code name}.
     *
     * @see #assertValidProperties()
     */
    public void initialize()
    {
        this.assertValidProperties();
        this.logger = LogFactory.getLog( this.getName() );
    }

    //----------------------------------------------------ContainerInitializer--
    //--Properties--------------------------------------------------------------

// <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:jdtausProperties
    // This section is managed by jdtaus-container-mojo.

    /**
     * Property {@code name}.
     * @serial
     */
    private java.lang.String pName;

    /**
     * Gets the value of property <code>name</code>.
     *
     * @return the value of property <code>name</code>.
     */
    public java.lang.String getName()
    {
        return this.pName;
    }

// </editor-fold>//GEN-END:jdtausProperties

    //--------------------------------------------------------------Properties--
    //--Logger------------------------------------------------------------------

    public boolean isDebugEnabled()
    {
        return this.logger.isDebugEnabled();
    }

    public void debug( String message )
    {
        this.logger.debug( message );
    }

    public void debug( Throwable throwable )
    {
        this.logger.debug( throwable.getMessage(), throwable );
    }

    public boolean isErrorEnabled()
    {
        return this.logger.isErrorEnabled();
    }

    public void error( String message )
    {
        this.logger.error( message );
    }

    public void error( Throwable throwable )
    {
        this.logger.error( throwable.getMessage(), throwable );
    }

    public boolean isFatalEnabled()
    {
        return this.logger.isFatalEnabled();
    }

    public void fatal( String message )
    {
        this.logger.fatal( message );
    }

    public void fatal( Throwable throwable )
    {
        this.logger.fatal( throwable.getMessage(), throwable );
    }

    public boolean isInfoEnabled()
    {
        return this.logger.isInfoEnabled();
    }

    public void info( String message )
    {
        this.logger.info( message );
    }

    public void info( Throwable throwable )
    {
        this.logger.info( throwable.getMessage(), throwable );
    }

    public boolean isTraceEnabled()
    {
        return this.logger.isTraceEnabled();
    }

    public void trace( String message )
    {
        this.logger.trace( message );
    }

    public void trace( Throwable throwable )
    {
        this.logger.trace( throwable.getMessage(), throwable );
    }

    public boolean isWarnEnabled()
    {
        return this.logger.isWarnEnabled();
    }

    public void warn( String message )
    {
        this.logger.warn( message );
    }

    public void warn( Throwable throwable )
    {
        this.logger.warn( throwable.getMessage(), throwable );
    }

    //------------------------------------------------------------------Logger--
    //--CommonsLoggingLogger----------------------------------------------------

    /** Creates a new {@code CommonsLoggingLogger} instance. */
    public CommonsLoggingLogger()
    {
        this( META );
        this.initialize();
    }

    /**
     * Creates a new {@code CommonsLoggingLogger} instance taking the name to
     * use for the commons logging logger.
     *
     * @param name the name to use for the commons logging logger.
     *
     * @throws PropertyException if {@code name} is {@code null} or the length
     * of {@code name} is {@code 0}.
     */
    public CommonsLoggingLogger( final String name )
    {
        this( META );
        this.pName = name;
        this.initialize();
    }

    /**
     * Checks configured properties.
     *
     * @throws PropertyException if property {@code name} is {@code null} or
     * of no length.
     */
    private void assertValidProperties()
    {
        if ( this.getName() == null || this.getName().length() <= 0 )
        {
            throw new PropertyException( "name", this.getName() );
        }
    }

    //----------------------------------------------------CommonsLoggingLogger--
}
